@@ -67,9 +67,8 @@ FilterAction::ReturnCode FilterActionRemoveHeader::process(ItemContext &context,
     KMime::Message::Ptr msg = context.item().payload<KMime::Message::Ptr>();
     const QByteArray param(mParameter.toLatin1());
     bool headerRemove = false;
-    while (msg->headerByType(param)) {
+    while (msg->removeHeader(param.constData())) {
         headerRemove = true;
-        msg->removeHeader(param);
     }
     if (headerRemove) {
         msg->assemble();
@@ -114,4 +113,3 @@ QString FilterActionRemoveHeader::informationAboutNotValidAction() const
 {
     return i18n("Header name undefined.");
 }
-
