@@ -62,8 +62,8 @@ bool FilterActionSetIdentity::argsFromStringInteractive(const QString &argsStr,
 
 FilterAction::ReturnCode FilterActionSetIdentity::process(ItemContext &context, bool applyOnOutbound) const
 {
-    const KIdentityManagement::Identity &ident =
-        KernelIf->identityManager()->identityForUoid(mParameter);
+    const KIdentityManagement::Identity &ident
+        = KernelIf->identityManager()->identityForUoid(mParameter);
 
     if (ident.isNull()) {
         return ErrorButGoOn;
@@ -134,4 +134,3 @@ void FilterActionSetIdentity::setParamWidgetValue(QWidget *paramWidget) const
 
     comboBox->setCurrentIdentity(mParameter);
 }
-
