@@ -33,18 +33,24 @@
 
 #include <QTimer>
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 class Q_DECL_HIDDEN FilterManager::Private
 {
 public:
     Private(FilterManager *qq)
-        : q(qq), mMailFilterAgentInterface(nullptr), mMonitor(new Akonadi::Monitor), mInitialized(false)
+        : q(qq)
+        , mMailFilterAgentInterface(nullptr)
+        , mMonitor(new Akonadi::Monitor)
+        , mInitialized(false)
     {
-        mMailFilterAgentInterface = new org::freedesktop::Akonadi::MailFilterAgent(QStringLiteral("org.freedesktop.Akonadi.MailFilterAgent"),
-                QStringLiteral("/MailFilterAgent"),
-                QDBusConnection::sessionBus(), q);
+        QString service = QStringLiteral("org.freedesktop.Akonadi.MailFilterAgent");
+        if (Akonadi::ServerManager::hasInstanceIdentifier()) {
+            service += QLatin1Char('.') + Akonadi::ServerManager::instanceIdentifier();
+        }
+
+        mMailFilterAgentInterface = new org::freedesktop::Akonadi::MailFilterAgent(service,
+                                                                                   QStringLiteral("/MailFilterAgent"),
+                                                                                   QDBusConnection::sessionBus(), q);
     }
 
     void readConfig();
@@ -89,7 +95,6 @@ void FilterManager::Private::clear()
     qDeleteAll(mFilters);
     mFilters.clear();
 }
-
 }
 
 using namespace MailCommon;
@@ -135,6 +140,16 @@ FilterManager::FilterManager()
     }
 }
 
+FilterManager::~FilterManager()
+{
+    cleanup();
+}
+
+void FilterManager::cleanup()
+{
+    d->clear();
+}
+
 void FilterManager::slotServerStateChanged(Akonadi::ServerManager::State state)
 {
     if (state == Akonadi::ServerManager::Running) {
@@ -300,4 +315,3 @@ void FilterManager::endUpdate()
     d->mMailFilterAgentInterface->reload();
     Q_EMIT filtersChanged();
 }
-
