@@ -31,9 +31,7 @@ using MailCommon::FilterLog;
 
 using namespace MailCommon;
 
-SearchRuleNumerical::SearchRuleNumerical(const QByteArray &field,
-        Function func,
-        const QString &contents)
+SearchRuleNumerical::SearchRuleNumerical(const QByteArray &field, Function func, const QString &contents)
     : SearchRule(field, func, contents)
 {
 }
@@ -58,11 +56,11 @@ bool SearchRuleNumerical::matches(const Akonadi::Item &item) const
     qint64 numericalMsgContents = 0;
     qint64 numericalValue = 0;
 
-    if (qstricmp(field(), "<size>") == 0) {
+    if (qstricmp(field().constData(), "<size>") == 0) {
         numericalMsgContents = item.size();
         numericalValue = contents().toLongLong();
         msgContents.setNum(numericalMsgContents);
-    } else if (qstricmp(field(), "<age in days>") == 0) {
+    } else if (qstricmp(field().constData(), "<age in days>") == 0) {
         QDateTime msgDateTime = msg->date()->dateTime();
         numericalMsgContents = msgDateTime.daysTo(QDateTime::currentDateTime());
         numericalValue = contents().toInt();
@@ -75,7 +73,7 @@ bool SearchRuleNumerical::matches(const Akonadi::Item &item) const
         QString msg = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>")
                        : QStringLiteral("<font color=#FF0000>0 = </font>"));
         msg += FilterLog::recode(asString());
-        msg += " ( <i>" + QString::number(numericalMsgContents) + "</i> )";
+        msg += QStringLiteral(" ( <i>") + QString::number(numericalMsgContents) + QStringLiteral("</i> )");
         FilterLog::instance()->add(msg, FilterLog::RuleResult);
     }
     return rc;
@@ -86,43 +84,44 @@ SearchRule::RequiredPart SearchRuleNumerical::requiredPart() const
     return SearchRule::Envelope;
 }
 
-bool SearchRuleNumerical::matchesInternal(long numericalValue,
-        long numericalMsgContents, const QString &msgContents) const
+bool SearchRuleNumerical::matchesInternal(long numericalValue, long numericalMsgContents, const QString &msgContents) const
 {
     switch (function()) {
     case SearchRule::FuncEquals:
-        return (numericalValue == numericalMsgContents);
+        return numericalValue == numericalMsgContents;
 
     case SearchRule::FuncNotEqual:
-        return (numericalValue != numericalMsgContents);
+        return numericalValue != numericalMsgContents;
 
     case SearchRule::FuncContains:
-        return (msgContents.contains(contents(), Qt::CaseInsensitive));
+        return msgContents.contains(contents(), Qt::CaseInsensitive);
 
     case SearchRule::FuncContainsNot:
-        return (!msgContents.contains(contents(), Qt::CaseInsensitive));
+        return !msgContents.contains(contents(), Qt::CaseInsensitive);
 
-    case SearchRule::FuncRegExp: {
+    case SearchRule::FuncRegExp:
+    {
         QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return (regexp.indexIn(msgContents) >= 0);
+        return regexp.indexIn(msgContents) >= 0;
     }
 
-    case SearchRule::FuncNotRegExp: {
+    case SearchRule::FuncNotRegExp:
+    {
         QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return (regexp.indexIn(msgContents) < 0);
+        return regexp.indexIn(msgContents) < 0;
     }
 
     case FuncIsGreater:
-        return (numericalMsgContents > numericalValue);
+        return numericalMsgContents > numericalValue;
 
     case FuncIsLessOrEqual:
-        return (numericalMsgContents <= numericalValue);
+        return numericalMsgContents <= numericalValue;
 
     case FuncIsLess:
-        return (numericalMsgContents < numericalValue);
+        return numericalMsgContents < numericalValue;
 
     case FuncIsGreaterOrEqual:
-        return (numericalMsgContents >= numericalValue);
+        return numericalMsgContents >= numericalValue;
 
     case FuncIsInAddressbook:  // since email-addresses are not numerical, I settle for false here
         return false;
@@ -141,11 +140,11 @@ void SearchRuleNumerical::addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &em
 {
     using namespace Akonadi;
     emptyIsNotAnError = false;
-    if (qstricmp(field(), "<size>") == 0) {
+    if (qstricmp(field().constData(), "<size>") == 0) {
         EmailSearchTerm term(EmailSearchTerm::ByteSize, contents().toInt(), akonadiComparator());
         term.setIsNegated(isNegated());
         groupTerm.addSubTerm(term);
-    } else if (qstricmp(field(), "<age in days>") == 0) {
+    } else if (qstricmp(field().constData(), "<age in days>") == 0) {
         QDate date(QDate::currentDate());
         date = date.addDays(contents().toInt());
         EmailSearchTerm term(EmailSearchTerm::HeaderOnlyDate, date, akonadiComparator());
