@@ -29,37 +29,64 @@ struct _statusNames {
 };
 
 static struct _statusNames statusNames[] = {
-    { "Important", Akonadi::MessageStatus::statusImportant() },
-    { "Unread", Akonadi::MessageStatus::statusUnread() },
-    { "Read", Akonadi::MessageStatus::statusRead() },
-    { "Deleted", Akonadi::MessageStatus::statusDeleted() },
-    { "Replied", Akonadi::MessageStatus::statusReplied() },
-    { "Forwarded", Akonadi::MessageStatus::statusForwarded() },
-    { "Queued", Akonadi::MessageStatus::statusQueued() },
-    { "Sent", Akonadi::MessageStatus::statusSent() },
-    { "Watched", Akonadi::MessageStatus::statusWatched() },
-    { "Ignored", Akonadi::MessageStatus::statusIgnored() },
-    { "Action Item", Akonadi::MessageStatus::statusToAct() },
-    { "Spam", Akonadi::MessageStatus::statusSpam() },
-    { "Ham", Akonadi::MessageStatus::statusHam() },
-    { "Has Attachment", Akonadi::MessageStatus::statusHasAttachment() }
+    {
+        "Important", Akonadi::MessageStatus::statusImportant()
+    },
+    {
+        "Unread", Akonadi::MessageStatus::statusUnread()
+    },
+    {
+        "Read", Akonadi::MessageStatus::statusRead()
+    },
+    {
+        "Deleted", Akonadi::MessageStatus::statusDeleted()
+    },
+    {
+        "Replied", Akonadi::MessageStatus::statusReplied()
+    },
+    {
+        "Forwarded", Akonadi::MessageStatus::statusForwarded()
+    },
+    {
+        "Queued", Akonadi::MessageStatus::statusQueued()
+    },
+    {
+        "Sent", Akonadi::MessageStatus::statusSent()
+    },
+    {
+        "Watched", Akonadi::MessageStatus::statusWatched()
+    },
+    {
+        "Ignored", Akonadi::MessageStatus::statusIgnored()
+    },
+    {
+        "Action Item", Akonadi::MessageStatus::statusToAct()
+    },
+    {
+        "Spam", Akonadi::MessageStatus::statusSpam()
+    },
+    {
+        "Ham", Akonadi::MessageStatus::statusHam()
+    },
+    {
+        "Has Attachment", Akonadi::MessageStatus::statusHasAttachment()
+    }
 };
 
-static const int numStatusNames =
-    sizeof statusNames / sizeof(struct _statusNames);
+static const int numStatusNames
+    = sizeof statusNames / sizeof(struct _statusNames);
 
 QString englishNameForStatus(const Akonadi::MessageStatus &status)
 {
     for (int i = 0; i < numStatusNames; ++i) {
         if (statusNames[i].status == status) {
-            return statusNames[i].name;
+            return QString::fromLatin1(statusNames[i].name);
         }
     }
     return QString();
 }
 
-SearchRuleStatus::SearchRuleStatus(const QByteArray &field,
-                                   Function func, const QString &aContents)
+SearchRuleStatus::SearchRuleStatus(const QByteArray &field, Function func, const QString &aContents)
     : SearchRule(field, func, aContents)
 {
     // the values are always in english, both from the conf file as well as
@@ -76,7 +103,7 @@ SearchRuleStatus::SearchRuleStatus(Akonadi::MessageStatus status, Function func)
 Akonadi::MessageStatus SearchRuleStatus::statusFromEnglishName(const QString &aStatusString)
 {
     for (int i = 0; i < numStatusNames; ++i) {
-        if (!aStatusString.compare(statusNames[i].name)) {
+        if (!aStatusString.compare(QString::fromLatin1(statusNames[i].name))) {
             return statusNames[i].status;
         }
     }
@@ -119,7 +146,7 @@ bool SearchRuleStatus::matches(const Akonadi::Item &item) const
         break;
     }
     if (FilterLog::instance()->isLogging()) {
-        QString msg = (rc ? "<font color=#00FF00>1 = </font>" : "<font color=#FF0000>0 = </font>");
+        QString msg = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>") : QStringLiteral("<font color=#FF0000>0 = </font>"));
         msg += FilterLog::recode(asString());
         FilterLog::instance()->add(msg, FilterLog::RuleResult);
     }
