@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,14 +27,13 @@
 
 class KActionCollection;
 
-namespace MailCommon
-{
+namespace MailCommon {
 class AddTagDialogPrivate;
 class MAILCOMMON_EXPORT AddTagDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit AddTagDialog(const QList<KActionCollection *> &actions, QWidget *parent = Q_NULLPTR);
+    explicit AddTagDialog(const QList<KActionCollection *> &actions, QWidget *parent = nullptr);
     ~AddTagDialog();
 
     void setTags(const QList<MailCommon::Tag::Ptr> &tags);
